==> haskell-yaml-0.11.0.0-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.11.0.0
id: yaml-0.11.0.0-EufHeUEvddD7XUSxtVqg4M
key: yaml-0.11.0.0-EufHeUEvddD7XUSxtVqg4M
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Data
abi: 99fffab3803d27c84eb0acaa9d3c3ef4
exposed: True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Paths_yaml
import-dirs: /usr/lib/ghc-8.6.4/site-local/yaml-0.11.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/yaml-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/yaml-0.11.0.0
hs-libraries: HSyaml-0.11.0.0-EufHeUEvddD7XUSxtVqg4M
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    libyaml-0.1.1.0-KOSQ21AWgvDLOmyFFFtQvw mtl-2.2.2
    resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.0.0-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.11.0.0
id: yaml-0.11.0.0-4zycI8uHbweAy6lJfUYfy5
key: yaml-0.11.0.0-4zycI8uHbweAy6lJfUYfy5
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Data
abi: cf0835121708450dec96a27c093c9071
exposed: True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Paths_yaml
import-dirs: /usr/lib/ghc-8.6.4/site-local/yaml-0.11.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/yaml-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/yaml-0.11.0.0
hs-libraries: HSyaml-0.11.0.0-4zycI8uHbweAy6lJfUYfy5
depends:
    aeson-1.4.2.0-QHLwhPMHVB663aXnGqoMq
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-DBoWDvZgddMAQw9hEqn0dn
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    libyaml-0.1.1.0-8mgreLfdqnsLLyl2tX2nPL mtl-2.2.2
    resourcet-1.2.2-1SMNkPIB95cIP5fLPJeWPc
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
